@@ -25,8 +25,8 @@
 #include <netdb.h>
 #include <netinet/in.h>
 
-#define Q_DIV
-#define Q_MUL
+#define Q_DIV(X) (X)
+#define Q_MUL(X) (X)
 #define DEV_QBSIZE DEV_BSIZE
 #define CADR (caddr_t)
 
