@@ -20,8 +20,8 @@
 #include <stdio.h>
 
 #define USE_IOCTL
-#define Q_DIV / 2
-#define Q_MUL * 2
+#define Q_DIV(X) ((X) / 2)
+#define Q_MUL(X) ((X) * 2)
 #define DEV_QBSIZE DEV_BSIZE
 #define CADR (caddr_t)
 
